==> k3d_0.4.3.0.orig.tar.gz: k3d-0.4.3.0/modules/channels/module.cpp <==
// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/** \file
		\brief Implements procedures required to export K-3D objects from the core module
		\author Timothy M. Shead (tshead@k-3d.com)
*/

#include <k3dsdk/module.h>

/// Namespace reserved for the channels plugin module, to protect public symbols from name clashes with other modules
namespace libk3dchannel
{

extern k3d::iplugin_factory& color_bezier_channel_factory();
extern k3d::iplugin_factory& scalar_bezier_channel_factory();

} // namespace libk3dchannel

K3D_MODULE_START(k3d::uuid(0xb1a41a98, 0x5bda4b88, 0x961ae594, 0xd3b739bb), Registry)
	Registry.register_factory(libk3dchannel::color_bezier_channel_factory());
	Registry.register_factory(libk3dchannel::scalar_bezier_channel_factory());
K3D_MODULE_END

==> k3d_0.5.0.35.orig.tar.gz: k3d-0.5.0.35/modules/channels/module.cpp <==
// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/** \file
		\brief Implements procedures required to export K-3D objects from the core module
		\author Timothy M. Shead (tshead@k-3d.com)
*/

#include <k3dsdk/module.h>

/// Namespace reserved for the channels plugin module, to protect public symbols from name clashes with other modules
namespace libk3dchannels
{

extern k3d::iplugin_factory& color_bezier_channel_factory();
extern k3d::iplugin_factory& scalar_bezier_channel_factory();

} // namespace libk3dchannels

K3D_MODULE_START(libk3dchannels, k3d::uuid(0xb1a41a98, 0x5bda4b88, 0x961ae594, 0xd3b739bb), Registry)
	Registry.register_factory(libk3dchannels::color_bezier_channel_factory());
	Registry.register_factory(libk3dchannels::scalar_bezier_channel_factory());
K3D_MODULE_END
